@@ -2,7 +2,7 @@ from arpeggio.cleanpeg import NOT, prefix
 from pulumi.resource import ResourceOptions
 import pulumi_azure_native.resources as resources
 
-def resource_group(stem, props, provider=None, parent_res=None, depends_on=None):
+def resource_group(stem, props, depends_on=None):
     rg = resources.ResourceGroup(
         f'rg-{stem}',
         resource_group_name=f'rg-{stem}',
